@@ -18,14 +18,14 @@ use Readonly 1.03;
 our (@EXPORT_OK, %EXPORT_TAGS);
 
 BEGIN {
-	our $VERSION = '0.20';
+	our $VERSION = '0.21';
 
 	XSLoader::load('File::Map', $VERSION);
 }
 
 my %export_data = (
 	'map'  => [qw/map_handle map_file map_anonymous unmap sys_map/],
-	extra  => [qw/remap sync pin unpin advise page_size/],
+	extra  => [qw/remap sync pin unpin advise protect/],
 	'lock' => [qw/wait_until notify broadcast lock_map/],
 );
 
@@ -36,7 +36,7 @@ while (my ($category, $functions) = each %export_data) {
 	}
 }
 
-my %protection_for = (
+Readonly our %PROTECTION_FOR => (
 	'<'  => PROT_READ,
 	'+<' => PROT_READ | PROT_WRITE,
 	'>'  => PROT_WRITE,
@@ -52,7 +52,7 @@ sub map_handle(\$*@) {
 	my $fh = qualify_to_ref($glob, caller);
 	$offset ||= 0;
 	$length ||= (-s $fh) - $offset;
-	_mmap_impl($var_ref, $length, $protection_for{ $mode || '<' }, MAP_SHARED | MAP_FILE, fileno $fh, $offset);
+	_mmap_impl($var_ref, $length, $PROTECTION_FOR{ $mode || '<' }, MAP_SHARED | MAP_FILE, fileno $fh, $offset);
 	return;
 }
 
@@ -62,7 +62,7 @@ sub map_file(\$@) {
 	$offset ||= 0;
 	open my $fh, $mode, $filename or croak "Couldn't open file $filename: $!";
 	$length ||= (-s $fh) - $offset;
-	_mmap_impl($var_ref, $length, $protection_for{$mode}, MAP_SHARED | MAP_FILE, fileno $fh, $offset);
+	_mmap_impl($var_ref, $length, $PROTECTION_FOR{$mode}, MAP_SHARED | MAP_FILE, fileno $fh, $offset);
 	close $fh or croak "Couldn't close $filename after mapping: $!";
 	return;
 }
@@ -101,6 +101,7 @@ Version 0.20
  map_file my $map, $filename;
  if ($map ne "foobar") {
      $map =~ s/bar/quz/g;
+     substr $map, 1024, 11, "Hello world";
  }
 
 =head1 DESCRIPTION
@@ -153,15 +154,17 @@ It has built-in support for thread synchronization.
 
 =head1 FUNCTIONS
 
+All functions take an lvalue as their first argument. This first argument has a prototype of C<\$>, B<be aware that this may change in a future release>.
+
 =head2 Mapping
 
-The following functions for mapping a variable are available for exportation. They all take an lvalue as their first argument, except page_size.
+The following functions for mapping a variable are available for exportation.
 
 =over 4
 
 =item * map_handle $lvalue, *filehandle, $mode = '<', $offset = 0, $length = -s(*handle) - $offset
 
-Use a filehandle to map into an lvalue. *filehandle may be a bareword, constant, scalar expression, typeglob, or a reference to a typeglob. $mode uses the same format as C<open> does. $offset and $length are byte positions in the file, and default to mapping the whole file.
+Use a filehandle to map into an lvalue. *filehandle may be a bareword, constant, scalar expression, typeglob, or a reference to a typeglob. $mode uses the same format as C<open> does (it currently accepts C<< < >>, C<< +< >>, C<< > >> and C<< +> >>). $offset and $length are byte positions in the file, and default to mapping the whole file.
 
 =item * map_file $lvalue, $filename, $mode = '<', $offset = 0, $length = -s($filename) - $offset
 
@@ -231,6 +234,10 @@ Specifies that the application expects that it will not access the mapped variab
 
 On some systems there may be more values available, but this can not be relied on. Unknown values for $advice will cause a warning but are further ignored.
 
+=item * protect $lvalue, $mode
+
+Change the memory protection of the mapping. $mode takes the same format as, but also accepts sys_map style constants.
+
 =back
 
 =head2 Locking
@@ -305,7 +312,7 @@ An attempt was made to C<sync>, C<remap>, C<unmap>, C<pin>, C<unpin>, C<advise>
 
 =item * Could not %f: %e
 
-Your OS didn't allow File::Map to do what you asked it to do for the reason specefied in %e
+Your OS didn't allow File::Map to do what you asked it to do for the reason specified in %e
 
 =item * Trying to %f on an unlocked map
 
@@ -315,10 +322,6 @@ You tried to C<wait_until>, C<notify> or C<broadcast> on an unlocked variable.
 
 A zero length anonymous map is not possible (or in any way useful).
 
-=item * Can't map empty file writably
-
-Empty files can't be mapped writably, because that wouldn't make any sense whatsoever.
-
 =back
 
 =head2 Warnings
@@ -335,12 +338,16 @@ This warning is additional to the previous one, warning you that you're losing d
 
 =item * Unknown advice '%s'
 
-You gave advise ani advice it didn't know. This is probably either a typo or a portability issue. This warning is only given when C<use warnings 'portable'> is in effect.
+You gave advise an advice it didn't know. This is probably either a typo or a portability issue. This warning is only given when C<use warnings 'portable'> is in effect.
 
 =item * Syncing a readonly map makes no sense
 
 C<sync> flushes changes to the map to the filesystem. This obviously is of little use when you can't change the map. This warning is only given when C<use warnings 'io'> is in effect.
 
+=item * Can't overwrite an empty map
+
+Overwriting an empty map is rather nonsensical, hence a warning is given when this is tried. This warning is only given when C<use warnings 'substr'> is in effect.
+
 =back
 
 =head1 DEPENDENCIES
@@ -407,7 +414,7 @@ L<http://search.cpan.org/dist/File-Map>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008, 2009 Leon Timmermans, all rights reserved.
+Copyright 2008, 2009, 2010 Leon Timmermans, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as perl itself.
